@@ -182,6 +182,8 @@ pub struct Remote {
 	/// Whether if the remote is set manually.
 	#[serde(skip_deserializing, default = "default_true")]
 	pub is_custom: bool,
+	/// Remote API URL.
+	pub api_url:   Option<String>,
 }
 
 /// Returns `true` for serde's `default` attribute.
@@ -209,6 +211,7 @@ impl Remote {
 			repo:      repo.into(),
 			token:     None,
 			is_custom: false,
+			api_url:   None,
 		}
 	}
 
