@@ -5,16 +5,9 @@ use serde::{
 	Deserialize,
 	Serialize,
 };
-use std::env;
 
 use super::*;
 
-/// Bitbucket REST API url.
-const BITBUCKET_API_URL: &str = "https://api.bitbucket.org/2.0/repositories";
-
-/// Environment variable for overriding the Bitbucket REST API url.
-const BITBUCKET_API_URL_ENV: &str = "BITBUCKET_API_URL";
-
 /// Log message to show while fetching data from Bitbucket.
 pub const START_FETCHING_MSG: &str = "Retrieving data from Bitbucket...";
 
@@ -33,6 +26,8 @@ pub(crate) const BITBUCKET_MAX_PAGE_PRS: usize = 50;
 pub struct BitbucketCommit {
 	/// SHA.
 	pub hash:   String,
+	/// Date of the commit
+	pub date:   String,
 	/// Author of the commit.
 	pub author: Option<BitbucketCommitAuthor>,
 }
@@ -45,6 +40,10 @@ impl RemoteCommit for BitbucketCommit {
 	fn username(&self) -> Option<String> {
 		self.author.clone().and_then(|v| v.login)
 	}
+
+	fn timestamp(&self) -> Option<i64> {
+		Some(self.convert_to_unix_timestamp(self.date.clone().as_str()))
+	}
 }
 
 /// <https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commits-get>
@@ -113,13 +112,13 @@ pub struct BitbucketPullRequestMergeCommit {
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct BitbucketPullRequest {
 	/// Pull request number.
-	pub id:               i64,
+	pub id:           i64,
 	/// Pull request title.
-	pub title:            Option<String>,
+	pub title:        Option<String>,
 	/// Bitbucket Pull Request Merge Commit
-	pub merge_commit_sha: BitbucketPullRequestMergeCommit,
+	pub merge_commit: BitbucketPullRequestMergeCommit,
 	/// Author of Pull Request
-	pub author:           BitbucketCommitAuthor,
+	pub author:       BitbucketCommitAuthor,
 }
 
 impl RemotePullRequest for BitbucketPullRequest {
@@ -136,7 +135,7 @@ impl RemotePullRequest for BitbucketPullRequest {
 	}
 
 	fn merge_commit(&self) -> Option<String> {
-		Some(self.merge_commit_sha.hash.clone())
+		Some(self.merge_commit.hash.clone())
 	}
 }
 
@@ -181,11 +180,8 @@ impl TryFrom<Remote> for BitbucketClient {
 }
 
 impl RemoteClient for BitbucketClient {
-	fn api_url() -> String {
-		env::var(BITBUCKET_API_URL_ENV)
-			.ok()
-			.unwrap_or_else(|| BITBUCKET_API_URL.to_string())
-	}
+	const API_URL: &'static str = "https://api.bitbucket.org/2.0/repositories";
+	const API_URL_ENV: &'static str = "BITBUCKET_API_URL";
 
 	fn remote(&self) -> Remote {
 		self.remote.clone()
@@ -221,3 +217,23 @@ impl BitbucketClient {
 			.collect())
 	}
 }
+
+#[cfg(test)]
+mod test {
+	use super::*;
+	use crate::remote::RemoteCommit;
+	use pretty_assertions::assert_eq;
+
+	#[test]
+	fn timestamp() {
+		let remote_commit = BitbucketCommit {
+			hash:   String::from("1d244937ee6ceb8e0314a4a201ba93a7a61f2071"),
+			author: Some(BitbucketCommitAuthor {
+				login: Some(String::from("orhun")),
+			}),
+			date:   String::from("2021-07-18T15:14:39+03:00"),
+		};
+
+		assert_eq!(Some(1626610479), remote_commit.timestamp());
+	}
+}
