@@ -5,16 +5,9 @@ use serde::{
 	Deserialize,
 	Serialize,
 };
-use std::env;
 
 use super::*;
 
-/// GitLab REST API url.
-const GITLAB_API_URL: &str = "https://gitlab.com/api/v4";
-
-/// Environment variable for overriding the GitLab REST API url.
-const GITLAB_API_URL_ENV: &str = "GITLAB_API_URL";
-
 /// Log message to show while fetching data from GitLab.
 pub const START_FETCHING_MSG: &str = "Retrieving data from GitLab...";
 
@@ -106,6 +99,10 @@ impl RemoteCommit for GitLabCommit {
 	fn username(&self) -> Option<String> {
 		Some(self.author_name.clone())
 	}
+
+	fn timestamp(&self) -> Option<i64> {
+		Some(self.convert_to_unix_timestamp(self.committed_date.clone().as_str()))
+	}
 }
 
 impl RemoteEntry for GitLabCommit {
@@ -244,11 +241,8 @@ impl TryFrom<Remote> for GitLabClient {
 }
 
 impl RemoteClient for GitLabClient {
-	fn api_url() -> String {
-		env::var(GITLAB_API_URL_ENV)
-			.ok()
-			.unwrap_or_else(|| GITLAB_API_URL.to_string())
-	}
+	const API_URL: &'static str = "https://gitlab.com/api/v4";
+	const API_URL_ENV: &'static str = "GITLAB_API_URL";
 
 	fn remote(&self) -> Remote {
 		self.remote.clone()
@@ -304,4 +298,16 @@ mod test {
 			GitLabProject::url(1, "https://gitlab.test.com/api/v4", &remote, 0)
 		);
 	}
+
+	#[test]
+	fn timestamp() {
+		let remote_commit = GitLabCommit {
+			id: String::from("1d244937ee6ceb8e0314a4a201ba93a7a61f2071"),
+			author_name: String::from("orhun"),
+			committed_date: String::from("2021-07-18T15:14:39+03:00"),
+			..Default::default()
+		};
+
+		assert_eq!(Some(1626610479), remote_commit.timestamp());
+	}
 }
